@@ -17,8 +17,9 @@ import os_vif
 import pyroute2
 from stevedore import driver as stv_driver
 
+from kuryr_kubernetes import utils
+
 _BINDING_NAMESPACE = 'kuryr_kubernetes.cni.binding'
-_IPDB = {}
 
 
 def _get_binding_driver(vif):
@@ -29,14 +30,11 @@ def _get_binding_driver(vif):
 
 
 def get_ipdb(netns=None):
-    try:
-        return _IPDB[netns]
-    except KeyError:
-        if netns:
-            ipdb = pyroute2.IPDB(nl=pyroute2.NetNS(netns))
-        else:
-            ipdb = pyroute2.IPDB()
-    _IPDB[netns] = ipdb
+    if netns:
+        netns = utils.convert_netns(netns)
+        ipdb = pyroute2.IPDB(nl=pyroute2.NetNS(netns))
+    else:
+        ipdb = pyroute2.IPDB()
     return ipdb
 
 
@@ -44,10 +42,12 @@ def _enable_ipv6(netns):
     # Docker disables IPv6 for --net=none containers
     # TODO(apuimedo) remove when it is no longer the case
     try:
-        self_ns_fd = open('/proc/self/ns/net')
+        netns = utils.convert_netns(netns)
+        path = utils.convert_netns('/proc/self/ns/net')
+        self_ns_fd = open(path)
         pyroute2.netns.setns(netns)
-        with open('/proc/sys/net/ipv6/conf/all/disable_ipv6',
-                  'w') as disable_ipv6:
+        path = utils.convert_netns('/proc/sys/net/ipv6/conf/all/disable_ipv6')
+        with open(path, 'w') as disable_ipv6:
             disable_ipv6.write('0')
     except Exception:
         raise
@@ -56,21 +56,23 @@ def _enable_ipv6(netns):
 
 
 def _configure_l3(vif, ifname, netns):
-    with get_ipdb(netns).interfaces[ifname] as iface:
-        for subnet in vif.network.subnets.objects:
-            if subnet.cidr.version == 6:
-                _enable_ipv6(netns)
-            for fip in subnet.ips.objects:
-                iface.add_ip('%s/%s' % (fip.address, subnet.cidr.prefixlen))
+    with get_ipdb(netns) as ipdb:
+        with ipdb.interfaces[ifname] as iface:
+            for subnet in vif.network.subnets.objects:
+                if subnet.cidr.version == 6:
+                    _enable_ipv6(netns)
+                for fip in subnet.ips.objects:
+                    iface.add_ip('%s/%s' % (fip.address,
+                                            subnet.cidr.prefixlen))
 
-    routes = get_ipdb(netns).routes
-    for subnet in vif.network.subnets.objects:
-        for route in subnet.routes.objects:
-            routes.add(gateway=str(route.gateway),
-                       dst=str(route.cidr)).commit()
-        if subnet.gateway:
-            routes.add(gateway=str(subnet.gateway),
-                       dst='default').commit()
+        routes = ipdb.routes
+        for subnet in vif.network.subnets.objects:
+            for route in subnet.routes.objects:
+                routes.add(gateway=str(route.gateway),
+                           dst=str(route.cidr)).commit()
+            if subnet.gateway:
+                routes.add(gateway=str(subnet.gateway),
+                           dst='default').commit()
 
 
 def connect(vif, instance_info, ifname, netns=None):
